summaryrefslogtreecommitdiffstats
path: root/webkit/appcache/appcache_storage.h
diff options
context:
space:
mode:
authorjennb@chromium.org <jennb@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-11-11 22:57:48 +0000
committerjennb@chromium.org <jennb@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-11-11 22:57:48 +0000
commit63f359f721c6f7ddc20c274b8e3e2b5df7b95a88 (patch)
tree17316cf5369ef8cf0627d2244b05e3948e27d7a7 /webkit/appcache/appcache_storage.h
parent712257e6ca930697de2a5c1d5e0a4311262e5a2c (diff)
downloadchromium_src-63f359f721c6f7ddc20c274b8e3e2b5df7b95a88.zip
chromium_src-63f359f721c6f7ddc20c274b8e3e2b5df7b95a88.tar.gz
chromium_src-63f359f721c6f7ddc20c274b8e3e2b5df7b95a88.tar.bz2
Change store group and newest cache API so that storage failure does not require storage clients to revert changes to group and so it's not racey.TEST=existing tests updatedBUG=none
Review URL: http://codereview.chromium.org/384029 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@31730 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'webkit/appcache/appcache_storage.h')
-rw-r--r--webkit/appcache/appcache_storage.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/webkit/appcache/appcache_storage.h b/webkit/appcache/appcache_storage.h
index 67717a5..02b6884 100644
--- a/webkit/appcache/appcache_storage.h
+++ b/webkit/appcache/appcache_storage.h
@@ -88,12 +88,14 @@ class AppCacheStorage {
// Schedules a group and its newest complete cache to be initially stored or
// incrementally updated with new changes. Upon completion the delegate
// will be called back. A group without a newest cache cannot be stored.
// It's a programming error to call this method with such a group. A
// side effect of storing a new newest cache is the removal of the group's
// old caches and responses from persistent storage (although they may still
- // linger in the in-memory working set until no longer needed).
+ // linger in the in-memory working set until no longer needed). The new
+ // cache will be added as the group's newest complete cache only if storage
+ // succeeds.
virtual void StoreGroupAndNewestCache(
- AppCacheGroup* group, Delegate* delegate) = 0;
+ AppCacheGroup* group, AppCache* newest_cache, Delegate* delegate) = 0;
// Schedules a query to identify a response for a main request. Upon
// completion the delegate will be called back.
@@ -88,12 +88,14 @@ class AppCacheStorage {
// incrementally updated with new changes. Upon completion the delegate
// will be called back. A group without a newest cache cannot be stored.
- // It's a programming error to call this method with such a group. A
+ // It's a programming error to call this method without a newest cache. A
// side effect of storing a new newest cache is the removal of the group's
// old caches and responses from persistent storage (although they may still